==> IDPmisc_1.1.17.tar.gz: IDPmisc/man/IDPmisc-package.Rd <==
\name{IDPmisc-package}
\alias{IDPmisc-package}
\alias{IDPmisc}
\docType{package}

\title{Utilities of Institute of Data Analyses and Process Design (www.idp.zhaw.ch)
}

\description{
  The IDPmisc package contains different high-level graphics functions
  for displaying large datasets, displaying circular data in a very
  flexible way, finding local maxima, brewing color ramps, drawing nice
  arrows, zooming 2D-plots, creating figures with differently colored
  margin and plot region. In addition, the package contains auxiliary
  functions for data manipulation like omitting observations with
  irregular values or selecting data by logical vectors, which include
  NAs. Other functions are especially useful in spectroscopy and
  analyses of environmental data: robust baseline fitting, finding peaks
  in spectra, plotting wind roses.
}

\details{
\tabular{ll}{
  Package: \tab IDPmisc\cr
  Type: \tab Package\cr
  Version: \tab 1.1.17\cr
  Date: \tab 2012-11-01\cr
  License: \tab  GPL (>= 3) (GNU Public Licence)\cr
}

}

\author{
Rene Locher, Andreas Ruckstuhl et al.

Maintainer: Rene Locher <rene.locher@zhaw.ch>
}

%% references{
%% ~ Literature or other references for background information ~~
%%

\keyword{ package }
\keyword{ dplot }
\keyword{ hplot }
\keyword{ manip }
\keyword{ utilities }
\keyword{ ts }
\keyword{ multivariate }

%% \seealso{
%% ~~ Optional links to other man pages, e.g. ~~
%% ~~ \code{\link[<pkg>:<pkg>-package]{<pkg>}} ~~
%% }
%%
%% \examples{
%% ~~ simple examples of the most important functions ~~
%% }

==> IDPmisc_1.1.18.tar.gz: IDPmisc/man/IDPmisc-package.Rd <==
\name{IDPmisc-package}
\alias{IDPmisc-package}
\alias{IDPmisc}
\docType{package}

\title{Utilities of Institute of Data Analyses and Process Design (www.zhaw.ch/idp)
}

\description{
  Different high-level graphics functions
  for displaying large datasets, displaying circular data in a very
  flexible way, finding local maxima, brewing color ramps, drawing nice
  arrows, zooming 2D-plots, creating figures with differently colored
  margin and plot region. In addition, the package contains auxiliary
  functions for data manipulation like omitting observations with
  irregular values or selecting data by logical vectors, which include
  NAs. Other functions are especially useful in spectroscopy and
  analyses of environmental data: robust baseline fitting, finding peaks
  in spectra, plotting wind roses.
}

\details{
  \tabular{ll}{
    Package: \tab IDPmisc\cr
    Type: \tab Package\cr
    Version: \tab 1.1.18\cr
    Date: \tab 2018-10-02\cr
    License: \tab  GPL (>= 3) (GNU Public Licence)\cr
  }
}

\author{
Rene Locher, Andreas Ruckstuhl et al.
Maintainer: Rene Locher <rene.locher@zhaw.ch>
}

%% references{
%% ~ Literature or other references for background information ~~
%%

\keyword{ package }
\keyword{ dplot }
\keyword{ hplot }
\keyword{ manip }
\keyword{ utilities }
\keyword{ ts }
\keyword{ multivariate }

%% \seealso{
%% ~~ Optional links to other man pages, e.g. ~~
%% ~~ \code{\link[<pkg>:<pkg>-package]{<pkg>}} ~~
%% }
%%
%% \examples{
%% ~~ simple examples of the most important functions ~~
%% }
